#
# spec file for package python-junos-eznc
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2017-2020, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
Name:           python-junos-eznc
Version:        2.6.7
Release:        1.4
Summary:        Junos 'EZ' automation for non-programmers
License:        Apache-2.0
URL:            https://www.github.com/Juniper/py-junos-eznc
Source:         https://github.com/Juniper/py-junos-eznc/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# replace deprecated nose by pytest
# https://github.com/Juniper/py-junos-eznc/pull/1078
Patch0:         python-junos-eznc-remove-nose.patch
# replace deprecated yamlordereddictloader by yamlloader
# https://github.com/Juniper/py-junos-eznc/pull/1078
Patch1:         python-junos-eznc-remove-yamlordereddictloader.patch
# https://github.com/Juniper/py-junos-eznc/issues/1176
Patch3:         python-junos-eznc-no-mock.patch
# PATCH-FIX-OPENSUSE python-311.patch gh#Juniper/py-junos-eznc#1236
Patch4:         python-311.patch
BuildRequires:  %{python_module Jinja2 >= 2.7.1}
BuildRequires:  %{python_module PyYAML >= 5.1}
BuildRequires:  %{python_module lxml >= 3.2.4}
BuildRequires:  %{python_module ncclient >= 0.6.13}
BuildRequires:  %{python_module netaddr}
BuildRequires:  %{python_module ntc-templates}
BuildRequires:  %{python_module paramiko >= 1.15.2}
BuildRequires:  %{python_module pyparsing}
BuildRequires:  %{python_module pyserial}
BuildRequires:  %{python_module pytest-forked}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scp >= 0.7.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module transitions}
BuildRequires:  %{python_module yamlloader}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Jinja2 >= 2.7.1
Requires:       python-PyYAML >= 5.1
Requires:       python-lxml >= 3.2.4
Requires:       python-ncclient >= 0.6.13
Requires:       python-netaddr
Requires:       python-ntc-templates
Requires:       python-paramiko >= 1.15.2
Requires:       python-pyparsing
Requires:       python-pyserial
Requires:       python-scp >= 0.7.0
Requires:       python-six
Requires:       python-transitions
BuildArch:      noarch
%python_subpackages

%description
Junos PyEZ is designed to provide the same capabilities as a user would have
on the Junos CLI, but in an environment built for automation tasks.
These capabilities include, but are not limited to:

 - Remote connectivity and management of Junos devices via NETCONF
 - Provide "facts" about the device
 - Retrieve "operational" or "run-state" information
 - Retrieve configuration information
 - Make configuration changes in unstructured and structured ways
 - Provide common utilities for tasks such as secure copy of files and
   software updates

%prep
%autosetup -p1 -n py-junos-eznc-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
donttest="nonemptydonttestprefix"
# https://github.com/Juniper/py-junos-eznc/issues/1109
python39_donttest=" or test_sw_put_ftp"
python310_donttest=" or test_sw_put_ftp"
%pytest -m "not functional" --forked -k "not ($donttest ${$python_donttest})"

%files %{python_files}
%license COPYRIGHT LICENSE
%doc README.txt README.md
%dir %{python_sitelib}/jnpr
%{python_sitelib}/jnpr/junos
%{python_sitelib}/junos_eznc-%{version}*-info
%{python_sitelib}/junos_eznc-%{version}*-nspkg.pth

%changelog
* Thu Mar  2 2023 Daniel Garcia <daniel.garcia@suse.com>
- Add python-311.patch to support python 3.11, gh#Juniper/py-junos-eznc#1236
- Remove python-junos-eznc-fix-unittests.patch, not needed anymore
- Update to 2.6.7:
  * Supported option to set look_for_keys with bool True/False #1234
  * Fixed build failure against setuptools #1231
- 2.6.6
  * Fixed reboot failing on other RE #1199
  * Fixed passing 'sleep' arg to StartShell run() #1202
  * Fixed PyEZ get-facts support for ACX model #1209
  * Fixed EthPortTable regex pattern #1215
  * Fixed StartShell UnboundLocalError #1203 #1211
- 2.6.5
  * Supported multi-gig ports for EthPortTable.yml #1177
  * Fixed on-box support for start shell types #1190 #1186
  * Fixed conn_open_timeout value was getting set None , changed it to
    default 30 seconds #1184
- 2.6.4
  * Supported start_shell options to choose the shell types (sh or csh) #995
  * Supported for python 3.9
  * Fixed Device facts current_re returns the SRX cluster node0 and
    node1 details with cluster ID 16 #1135
  * Fixed upgrade ncclient version 0.6.13, updated requirements.txt to
    install ncclient==0.6.13 #1153
  * Fixed deprecation warning due to invalid escape sequences #1034
  * Fixed Unit tests test_sw_put_ftp failure #1165
* Tue May  3 2022 pgajdos@suse.com
- added patches
  fix https://github.com/Juniper/py-junos-eznc/issues/1176
  + python-junos-eznc-no-mock.patch
* Tue May  3 2022 pgajdos@suse.com
- added patches
  fix https://github.com/Juniper/py-junos-eznc/commit/96f25bb8aa006e12e48902a91a1dc6ff595bdd2d
  + python-junos-eznc-fix-unittests.patch
* Tue Jan 11 2022 Ben Greiner <code@bnavigator.de>
- remove selectors2 build requirement: It's unmaintained and pulled
  in by ncclient only if necessary, i.e. on python <= 3.4, but
  nowhere declared or used by this junos-eznc.
* Wed Oct 13 2021 ecsos <ecsos@opensuse.org>
- Update to version 2.6.3
  * Enhancements done
    Adding ignore warning for rollback api #1131
    Add escaped $ Bourne-style shell prompt support #868
  * Bugs Fixed
  - Fix for junos versions returning a bool value for config diff
    if there are no changes #1093
  - Handle ncclient timeout exception at close. #787
  - Newer junos versions return a bool for config diff and not
    etree if there are no changes #1093
- Changes from 2.6.2
  * Bugs Fixed
  - Fix for evo device as Password prompt comes directly during
    telnet #1112
- Changes from 2.6.1
  * Enhancement Added
  - Flag for json.loads() for special character like newline was
    made false by default. #1029
  * Bugs Fixed
  - Transform function modified only for the rpc and set back to
    original value. #1108
  - Skip the values returned in re-list without numbers during
    multi re software install #1099
  - getiterator() replaced with iter() as was deprecated in
    Python 3.2 and removed in Python 3.9 #1110
- Drop python-junos-eznc-py39xml.patch because now in upstream.
* Mon Apr 26 2021 Ben Greiner <code@bnavigator.de>
- Update to 2.6.0
  * Python 2 support removed from this release.
  * Session-id variable added to support telnet based persistent
    connection in Juniper supported ansible collections.
- Add python-junos-eznc-py39xml.patch gh#Juniper/py-junos-eznc#1110
- Skip failing test gh#Juniper/py-junos-eznc/issues/1109
* Thu Oct 29 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.5.4
  Features Added
  * cRPD model check to be added for on-box junos.
  Bugs Fixed
  * support use-fast-diff in diff/pdff function.
  * Zeroize handling modified for scenario where only warning is
    returned in the rpc-reply.
  * ntc_template and textfsm module's installation made optional
    and to be done explicitly if one want to use PyEZ table/view
    for other vendors cli o/p parsing.
  * Checksum algorithm argument to be passed during remote
    checksum in software installation.
  * docstring initialized with empty string as it becomes empty
    if optimization flag is added.
* Fri Sep 18 2020 pgajdos@suse.com
- use pytest instead of nose and replace deprecated
  yamlordereddictloader by yamlloader
- added patches:
  + python-junos-eznc-remove-nose.patch
  + python-junos-eznc-remove-yamlordereddictloader.patch
* Fri Aug 28 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.5.3
  Bugs fixed:
  * vmhost single re based image upgrade is failing while reboot.
* Sat Aug 22 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.5.2
  * juniper_junos_system fails when (vmhost) rebooting MX204 router
  * Testcase failing in PyEZ after ncclient upgrade
  * Wheel support for version integrated with versioneer.
  * rpc-reply during reboot parsing gives error
* Fri Jul 31 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.5.1
  * Adding monitor-failure information in juniper_junos_facts
    output
  * Raise exception when dev.cli fails with exception
  * Device version fix for srx when cluster id greater than 15
* Tue Jun 30 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.5.0
  Features Added
  * Versioneer support added for the code.
  * Changes for ansible actions of the reboot, shutdown to be
    handled in PyEZ
  Bugs Fixed
  * sax parser filter generation generic logic
  * Changes for the msg displayed in case of failure in software
    update
  * ntc_template latest version uses textfsm 1.1.0 #1042
  * drop hard dependency on unittest2 #1040
- Drop patch (fixed upstream)
  * python-junos-eznc-no-unittest2.patch
* Thu Jun  4 2020 pgajdos@suse.com
- version update to 2.4.1
  [#]# [1.4.0]
  [#]## Fixed
  - [#617] - IOS show ip ospf database router: Removed reliance on static spacing
  - [#620] - NXOS show fex: Allow spaces in descriptions
  - [#621] - Juniper show arp, etc.: Account for virtual chassis output (`{master:0}`)
  - [#626] - ASA show vpn-sessiondb anyconnect: Require index, capture different format style
  - [#650] - IOS show ip ospf database network: Change to allow one or more whitespace at the beginning of the line rather than 1 or more due to different output
  - [#647] - ASA show route: Allow multiline route statements
  - [#659] - IOS show mac address-table: Allow VLAN to be non-whitespace to allow N/A as an option
  [#]## Added
  - [#618] - IOS show ip ospf database network: New template
  - [#619] - HP Comware display lldp neighbor information verbose: New template
  - [#625] - ASA show vpn-sessiondb anyconnect: New template
  - [#628] - Cisco WLC show mobility sum: New template
  - [#631] - ASA show vpn-sessiondb anyconnect: Account for new data for assigned/public IP, group policy, and tunnel group
  - [#629] - ASA show crypto ipsec sa - Add LOCAL_ADDRESS_NAME, CURRENT_PEER_NAME, DYNAMIC_PEER_NAME, LOCAL_CRYPTO_ENDPOINT_NAME, REMOTE_CRYPTO_ENDPOINT_NAME
  - [#632] - ASA show nat: Added SERVICE_PROTOCOL
  - [#635] - IOS show ip route summary: New template
  - [#636] - ASA show vpn-sessiondb: New template
  - [#638] - ASA show inventory: Capture PID and VID withoout serial
  - [#637] - Cisco WLC show band select: New template
  [#]# [1.4.0]
  [#]## Fixed
  - [#548] IOS show mac address-table: Account for Total Mac Addresses
  - [#565] IOS show license: Avoid trailing spaces for features
  - [#575] NXOS show version: Match N5K PLATFORM & LAST_REBOOT captures split words
  - [#574] ASA show failover: Account for new output (IPS)
  - [#577] IOS show mac address-table: Account for Multicast Entries
  - [#582] NXOS show interface transceiver: Remove requirement for TYPE
  - [#585] IOS show mac address-table: Fixed ordering for TYPE2
  - [#587] IOS show interfaces switchport: Account for Vepa Enabled and Operational Dot1q Ethertype
  - [#584] IOS show switch detail: Account for Mac persistency wait time
  - [#589] EOS show ip route: Filldown for DISTANCE and METRIC - Added new data formats for VRF and NEXT_HOP and INTERFACE
  - [#592] Fortinet get router info bgp summary: Account for more data, fix UP_DOWN regex from word to non-whitespace
  - [#603] IOS show ip access-list: Update PROTOCOL to capture numbered protocols
  - [610] Aruba os show arp: Fix tests to have the full output from the command and device
  - [#608] Vyatta VyOS show interfaces: Capture IP_ADDRESS with or without netmask
  - [#614] IOS show interfaces status: Remove reliance on whitespaces
  [#]## Added
  - [#406] Testing: Add yamllint to test suite
  - [#407] Testing: Add python black to test suite
  - [#553] IOS show lldp neighbors: Added CAPABILITIES capture group
  - [#554] IOS show logging: New template
  - [#563] IOS show interfaces switchport: Added ADMIN_MDOE capture group
  - [#562] ASA show logging: New template
  - [#564] NXOS show interface transceiver: New template
  - [#567] XR show arp: New template
  - [#572] IOS show lldp neighbors detail: Added SERIAL capture group
  - [#573] ASA show arp: New template
  - [#578] Fortinet get system interface: New template
  - [#576] Huawei VRP display lldp neighbor: New template
  - [#581] Cisco WLC show vlan sum: New template
  - [#580] XR show interfaces summary: New template
  - [#590] IOS show ip bgp neighbors: New template
  - [#591] NXOS show vdc: New template
  - [#595] Checkpoint GAIA show arp dynamic all: New template
  - [#593] IOS show module: New template
  - [#597] Huwai VRP display version: New template
  - [#602] NXOS show vrf interface: New template
  - [#598] IOS show running-config partition access list: Added TCP_FLAG capture group
  - [#598] IOS show running-config partition access list: Convert COMMENT to list
  - [#598] IOS show running-config partition access list: Update PROTOCOL to include numbered protocols
  - [#596] XR admin show environment power: New template
  - [#594] Aruba os show arp: New template
  - [#605] SG300 show version: New template
  - [#604] NXOS show vlan: Added INTERFACES capture group, Require VLAN_ID
  - [#600] IOS show mpls interfaces: New template
  - [#599] IOS show etherchannel summary: New template
  - [#611] NXOS show interface: Added MODE capture group
  - [#612] NXOS show interfaces switchport: Added ACCESS_VLAN_NAME and NATIVE_VLAN_NAME capture groups
  - [#609] HP Comware display ip interface: New template
  - [#606] IOS show ip ospf database router: New template
  [#]## Changed
  - [#406] Helpers: Added development_helpers cli utility to replace existing helpers
- python3 package only, as ntc-templates is python3 only
- added patches
  https://github.com/Juniper/py-junos-eznc/pull/1040
  + python-junos-eznc-no-unittest2.patch
* Tue Dec 10 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.3.1
  Bugfix release:
  * Handled a check for pending Junos OS or package installation
  * Fixed MetaPathLoader support only for jnpr.junos* modules
  * Fixed huge tree XML support
  * Fixed Junos sax parser issue for filter_xml broken
* Mon Oct  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update tests and dependencies to make the package work
* Sun Sep 29 2019 Martin Hauke <mardnh@gmx.de>
- Use github source URL
- Add python-transitions to (Build)Requires
- Update to version 2.3.0
  Features Added
  * TableView extended for vty/cli unstructured command
  * Added junos SAX parser feature
  * Added TableView Null Key support
  * Added command tables
  * Added reboot support for junos vmhost platform
  * Added ElsEthernetSwitchingTable TableView
  * Added callback functionality to ftp get
  * Extended start shell support for Bourne shell
  * Added at option support for sw.reboot() and sw.poweroff()
  * Added generalized function for ssh-client
  Bugs Fixed
  * Updated fact collection for srx platform
  * Supports new ssh private key format
  * Handled exception in dev.close()
  * Updated file transfers to use context manager to open files
  * Fixed reboot and poweroff behavior
* Thu Mar  7 2019 Daniel Molkentin <daniel.molkentin@suse.com>
- Fix singlespec Requires
* Wed Mar  6 2019 Daniel Molkentin <daniel.molkentin@suse.com>
- Update to 2.2.0
  No changelog provided
* Mon Aug  7 2017 mardnh@gmx.de
- Update to version 2.1.5
- Convert to singlespec
* Sat Sep  3 2016 mardnh@gmx.de
- initial package, version 2.0.0
